/*
REPLICATION FILE FOR:

Kai Gehring and Valentin Lang:
Stigma or Cushion? IMF Programs and Sovereign Creditworthiness,
 Journal of Development Economics 146 (2020).

*/

*version 16
drop _all
clear matrix
clear mata
set mat 5000
set more off,perm

********************************************************************************
*SET DIRECTORIES
*Kai work
local DIR ="C:\Users\gehring\Documents\Dropbox\IMF Rating\Stata"
cap  cd "`DIR'"

*Kai Home
local DIR ="C:\Users\kai_g\Dropbox\IMF Rating\Stata"
cap  cd "`DIR'"

*Valentin
global DIR = "/Users/lang/Dropbox/IMF_Rating/Stata"
cap cd "$DIR"
********************************************************************************


*CREATE NECESSARY DIRECTORIES
*** Create folders "processed"(where transformed data are stored) and "tables" (where tables are stored)
program define confirmdir, rclass
		local cwd `"`c(pwd)'"'
		quietly capture cd `"`1'"'
		local confirmdir=_rc 
		quietly cd `"`cwd'"'
		return local confirmdir `"`confirmdir'"'
	end 
		confirmdir `"processed"'	  	/* does folder "bearbeitet" exist? */
			if `r(confirmdir)'!=0  {  	/* folder does not yet exist */
				mkdir "processed"  	/* makes the folder  */
							  } 
			  else {
				di "folder processed already exists"
				}
		confirmdir `"tables"'		  /* does folder "tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "tables"  /* makes the folder  */
							  } 
			  else {
				di "folder tables already exists"
				}
		confirmdir `"output"'		  /* does folder "tables" exist? */
			if `r(confirmdir)'!=0  {  /* folder does not yet exist */
				mkdir "output"  /* makes the folder  */
							  } 
			  else {
				di "folder output already exists"
				}
	program drop confirmdir

*	capture log using "tables/LangGehring.log", replace


********************************************************************************

*INSTALL NECESSARY COMMANDS
capture net install mdesc , replace from(http://fmwww.bc.edu/RePEc/bocode/m/)
capture net install ivreg2 , replace from(http://fmwww.bc.edu/RePEc/bocode/i/)
capture net install xtivreg2 , replace from(http://fmwww.bc.edu/RePEc/bocode/x/)
capture net install ranktest , replace from(http://fmwww.bc.edu/RePEc/bocode/r/)
capture net install reghdfe , replace from(http://fmwww.bc.edu/RePEc/bocode/r)
capture net install hilo , replace  from(https://stats.idre.ucla.edu/stat/stata/ado/analysis/)
capture net install winsor2 , replace  from(http://fmwww.bc.edu/RePEc/bocode/w)
capture ssc install clustse, replace
capture net install unique, replace
ssc install spmap, replace
ssc install regsave
ssc install coefplot

net install scheme_virdis, from(https://raw.github.com/vikjam/stata-scheme-virdis/master/) replace
net install gr0075.pkg
net install _gwtmean.pkg
********************************************************************************


*FIGURES

*FIGURE 1: MAP

 
 use "world-d",clear
  ren CCode code
  cap noisily drop _merge
  *drop if code==""
   merge m:m code using "processed/IMFRATING2.dta",force keepusing(IMFprogram IMFagreement  year)
   sort code year
collapse (mean) IMFprogram (sum) S_IMFprogram=IMFprogram, by (code REGION id  NAME)
replace IMFprogram=0 if IMFprogram==.
replace S_IMFprogram=0 if S_IMFprogram==.
*keep if period==12

colorpalette hsv, heat n(6) reverse
colorpalette Blues , select( 1 5 6 7 8 9) 
spmap IMFprogram using  "world-c" if NAME!="Antarctica", id(id) clmethod(custom) clbreaks(0 0.00001 .125 .25 .375 .5 1)  ///
legenda(on) legcount legstyle(2)   ///	
 legjunction(" - ") ///
 fcolor(`r(p)') ///
 ocolor(gs5 ..) osize(vvthin ..) /// 
legend(size(medium) symysize(*2.5) symxsize(*2.5) forcesize) name("IMFprogram", replace) 


gr_edit legend.plotregion1.label[1].text = {}
gr_edit legend.plotregion1.label[1].text.Arrpush "more than 20 years"

gr_edit legend.plotregion1.label[2].text = {}
gr_edit legend.plotregion1.label[2].text.Arrpush "15-20 years"

gr_edit legend.plotregion1.label[3].text = {}
gr_edit legend.plotregion1.label[3].text.Arrpush "10-15 years"

gr_edit legend.plotregion1.label[4].text = {}
gr_edit legend.plotregion1.label[4].text.Arrpush "5-10 years"

gr_edit legend.plotregion1.label[5].text = {}
gr_edit legend.plotregion1.label[5].text.Arrpush "less than 5 years"

gr_edit legend.plotregion1.label[6].text = {}
gr_edit legend.plotregion1.label[6].text.Arrpush "never"


graph export "output/FIGURE1_MAP.png", as(png) replace

graph close








*FIGURE 2: RATING TRENDS AROUND IMF STARTS


use "processed/IMFRATINGMONTHLY2", clear


xtset countryID monthcount
sort countryID monthcount

bysort monthsafterfirstIMFstart: egen mean_meandevrating = mean(devmean_rat1Esp) if totalIMFmonths != 0

twoway line mean_meandevrating monthsafterfirstIMFstart if -120 < monthsafterfirstIMFstart & monthsafterfirstIMFstart < 120 & totalIMFmonths != 0 ///
, graphregion(color(white)) bgcolor(white)   ///
color(black) ///
xtitle("Months before/after start of first IMF program") ///
ytitle("Deviation from average country rating") ///
ylabel(, angle(0)  ) ///
xline(0, lpattern(dash) lcolor(maroon)) 
graph export "output/FIGURE2_TREND_LONG.png", replace

*for Appendix or right next to it:
twoway line mean_meandevrating monthsafterfirstIMFstart if -12 < monthsafterfirstIMFstart & monthsafterfirstIMFstart < 12 & totalIMFmonths != 0 ///
, graphregion(color(white)) bgcolor(white) ///
color(black) ///
xtitle("Months before/after start of first IMF program") ///
ytitle("Deviation from average country rating") ///
ylabel(, angle(0) ) ///
xline(0, lpattern(dash) lcolor(cranberry)) 
graph export "output/FIGUREA1_TREND_SHORT.png", replace













* FIGURE 3: FIRST STAGE
use  "processed/IMFRATING2",clear

*controls:
global control		ln_gdp_pc_const gdp_growth inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

	*IV global cycle controls
	cap drop IVgrowth IVcrises IVgrowthhic IVfdi
	gen IVgrowth = IMFprob * worldGDPgrowth
	gen IVcrises = IMFprob * crises_LV 
	gen IVfdi = IMFprob * d1_fdiin2gdp_hic

	*All other controls times liquidity as controls
	sort countryID year
	foreach var of varlist $control {
	gen `var'Xliquid = `var' * lnIMFgrossliquidity
	gen l4_`var'Xliquid = l4.`var'Xliquid
	}
					
					
cap drop sample
xtivreg2 rat1Esp (IMFprogram = IVLQR)  IMFprob l4.($control) l4_* IVgrowth IVcrises IVfdi yeardummies* , fe cluster(countryID) first savefirst savefprefix(Xtab15)
cap drop sample
gen sample = 1  if e(sample)

xtreg IMFprogram c.lnIMFgrossliquidity##c.IMFprob l4.($control) l4_* IVgrowth IVcrises IVfdi  if sample == 1, fe cluster(country_ID)


margins , dydx(IMFprob) at((mean) _all lnIMFgrossliquidity=(4(0.25)8) )

marginsplot, yline(0) scheme(s1mono) recast(line) /*recastci(rarea)*/  ///
 ci1opts(fintensity(30)) ///
 addplot(hist lnIMFgrossliquidity if sample == 1, ///
 width(0.25) start(4)  color(maroon%80) scheme(s1mono) ) ///
	xtitle("IMF liquidity (ln)") ytitle("Marginal Effect of IMF probability on IMF program") ///
	title("") legend(off) xlabel(4(0.5)8) ylabel(, angle(0))
graph export "output/FIGURE3_FIRSTSTAGE.png", replace








 
 
 


*FIGURE 4: TRENDS AND FAKE TRENDS
use  "processed/IMFRATING2",clear

xtivreg2 rat1Esp (IMFprogram = IVLQR)  IMFprob   yeardummies*, fe cluster(countryID) first savefirst savefprefix(Xtab15)
codebook  IMFprob_const if e(sample) 
centile IMFprob_const if e(sample), centile( 50 85) 
local fiftyProb=r(c_1)
local eightyProb=r(c_2)
display `fiftyProb'
scalar fiftyProb=r(c_1)
scalar eightyProb=r(c_2)

gen highIMFprob=0 if IMFprob_const!=. & IMFprob_const==0
replace highIMFprob=1 if IMFprob_const>0 &IMFprob_const<=eightyProb  &  IMFprob_const!=.
replace highIMFprob=2 if IMFprob_const>eightyProb &IMFprob_const!=.
bys highIMFprob year: egen rat1Esp_hilowIMF= mean(rat1Esp)    if e(sample)


twoway   (  line       rat1Esp_hilowIMF year if highIMFprob==0 &e(sample)& year>=1990, lwidth( medium  ) lpattern(dot) color(midblue) msize(small) graphregion(color(white)) ) ///
(  line       rat1Esp_hilowIMF year if highIMFprob==1&e(sample)& year>=1990, lwidth( medium  ) msize(small) color("green") )  ///
(  line       rat1Esp_hilowIMF year if highIMFprob==2&e(sample)& year>=1990, lwidth( medium  )  msize(small) color("maroon")  )  ///
( line   lnIMFgrossliquidity year if country == "Germany" & e(sample) & year>=1990,  msize(medsmall) lpattern(dash) color(gs4) scheme(s1mono) yaxis(2 )    ), ///
		 legend(off) 		///
		xtitle("year", margin(medsmall)) ///
		yscale(range(0 25))  ymtick(5 10 15 21) ylabel(1 5 10 15 21)  ///
		ytitle("Ratings", margin(medsmall)) ytitle(IMF Liquidity Ratio, margin(medium) axis(2)) ///
		text(15 1996 "low IMF probability", color(green) size(medsmall)) /// 13 2001
		text(11 1994 "high IMF probability", color(maroon) size(medsmall)) /// 7 2009
		text(21 1997 "no IMF programs", color(midblue) size(medsmall)) /// 21 1995
		text(23 2011 "IMF liquidity", color(black) size(medsmall)) //

	graph export "output/FIGURE4A_TRENDS.png", width(4000) replace	

		 
 gen faketrend = .
 replace faketrend = 4.5 if year == 1990
 replace faketrend = 4.5 if year == 1991
 replace faketrend = 4.5 if year == 1992
 replace faketrend = 4.5 if year == 1993
 replace faketrend = 4.5 if year == 1994
 replace faketrend = 4.5 if year == 1995
 replace faketrend = 4.5 if year == 1996
 replace faketrend = 4.5 if year == 1997
 replace faketrend = 4.5 if year == 1998
 replace faketrend = 4.5 if year == 1999
 replace faketrend = 4.7 if year == 2000
 replace faketrend = 5.0 if year == 2001
 replace faketrend = 5.4 if year == 2002
 replace faketrend = 6.0 if year == 2003
 replace faketrend = 6.7 if year == 2004
 replace faketrend = 7.4 if year == 2005
 replace faketrend = 8.2 if year == 2006
 replace faketrend = 9 if year == 2007
 replace faketrend = 9.9 if year == 2008
 replace faketrend = 10.9 if year == 2009
 replace faketrend = 12 if year == 2010
 replace faketrend = 13.1 if year == 2011
 replace faketrend = 14.3 if year == 2012
  replace faketrend = 15.5 if year == 2013
  
  cap gen faketrend2 = 16

 twoway   (  line       faketrend2 year if highIMFprob==1&e(sample)& year>=1990, lwidth( medium  ) msize(small) color("green") )  ///
		(  line       faketrend year if country == "Germany" & year>=1990, lwidth( medium  )  msize(small) color("maroon")  )  ///
		( line   lnIMFgrossliquidity year if country == "Germany" & e(sample) & year>=1990,  msize(medsmall) lpattern(dash) color(gs4) scheme(s1mono) yaxis(2 )    ), ///
		 legend(off) 		///
		xtitle("year", margin(medsmall)) ///
		yscale(range(0 25))  ymtick(5 10 15 21) ylabel(1 5 10 15 21)  ///
		ytitle("Ratings", margin(medsmall)) ytitle(IMF Liquidity Ratio, margin(medium) axis(2)) ///
		text(18 1996 "low IMF probability" "(fabricated)", color(green) size(medsmall)) /// 13 2001
		text(7 2010 "high IMF probability" "(fabricated)" , color(maroon) size(medsmall)) /// 7 2009
		text(23 2011 "IMF liquidity", color(black) size(medsmall)) //
		
 graph export "output/FIGURE4B_FAKETRENDS.png", width(4000) replace	

 
 
 
 
 
 

 
 
 
use  "processed/IMFRATING2", clear 


 global control		ln_gdp_pc_const gdp_growth inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

					
	cap drop sample
	xtivreg2 rat1Esp (IMFprogram = IVLQR)  IMFprob l4.($control)  yeardummies*, fe cluster(countryID) 
	gen sample = 1 if e(sample)

	*gen IV
	cap drop IVLQR
	gen IVLQR = IMFprob * lnIMFgrossliquidity
	

	*variables in differences
	sort countryID year
	gen d1_rat1Esp = rat1Esp - l.rat1Esp
	gen d2_rat1Esp = rat1Esp - l2.rat1Esp
	gen d1_IMFprogram = IMFprogram - l.IMFprogram
	
	cap drop d45X* 
	foreach var of varlist $control {
		gen d45X_`var' = l4.`var' - l5.`var'
	}

	*IV global cycle controls
	cap drop IVgrowth IVcrises IVgrowthhic IVfdi
	gen IVgrowth = IMFprob * worldGDPgrowth
	gen IVcrises = IMFprob * crises_LV 
	gen IVfdi = IMFprob * d1_fdiin2gdp_hic

	*All other controls times liquidity as controls
	sort countryID year
	foreach var of varlist $control {
	gen `var'Xliquid = `var' * lnIMFgrossliquidity
	gen l4_`var'Xliquid = l4.`var'Xliquid
	}
	
cap est drop tab1* tabfirst1*


*Column 1: OLS
cap est drop tab1*
reg rat1Esp IMFprogram  if sample== 1, cluster(countryID) // for constant sample for comparability
est store tab11
estadd local CountryFE = "No"
estadd local YearFE = "No"
estadd local Controls="No"
estadd local Method = "OLS"

*Column 2: cFE
xtreg rat1Esp IMFprogram  if sample== 1, fe cluster(countryID)
est store tab12
estadd local CountryFE = "Yes"
estadd local YearFE = "No"
estadd local Controls="No"
estadd local Method = "FE"

*Column 3: yFE
xtreg rat1Esp IMFprogram yeardummies*  if sample== 1, fe cluster(countryID)
est store tab13
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local Controls="No"
estadd local Method = "FE"

*Column 4: controls
xtivreg2 rat1Esp IMFprogram  l4.($control)  yeardummies* if sample== 1, fe cluster(countryID)
est store tab14
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local Controls="Yes"
estadd local Method = "FE"

*Column 5: FD
rename IMFprogram IMFprogramreal 
rename d1_IMFprogram IMFprogram // this is done to make coefplot nicer

reg d1_rat1Esp IMFprogram d45X* yeardummies* if sample== 1,  cluster(countryID)
est store tab15
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local Controls="Yes"
estadd local Method = "FD"

rename IMFprogram d1_IMFprogram 
rename IMFprogramreal IMFprogram 

*Column 6: IV
xtivreg2 rat1Esp (IMFprogram = IVLQR) IMFprob l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if sample== 1, fe cluster(countryID) first savefirst savefprefix(tabfirst16)
est store tab16
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local Controls="Yes"
estadd local Method = "IV"

estout tab1* using "output/Table1_baseline.txt", title("Table 1 - Baseline S&P") ///
 replace  delimiter(_tab) label noabbrev style(tab) collabels(none) /// 
 keep(IMFprogram) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
 stats(N r2 CountryFE YearFE Controls idp widstat, fmt(0 3 0 0 0 3 3) ///
 label("Observations" "Adjusted R-squared" "Country FE" "Year FE"  "Controls (t-4)"  "KP underid. p" "KP weak id. (F)")) 

 estout tabfirst1* using "output/Table1_baseline.txt",  ///
 append delimiter(_tab)  label noabbrev style(tab)  collabels(none) ///
 extracols(1, 1 ,1 ,1, 1) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
  keep(IMFprob IVLQR  ) order( IVLQR  IMFprob)  mlabel(none)
 

 
*For first-differences comment:	
ivreg2 d1.rat1Esp (IMFagreement = d1.IVLQR) d.IMFprob ///
d.IVgrowth d.IVcrises d.IVfdi ///
 d1.(l4.($control))  d1.(l4_*liquid) ///
 yeardummies* if sample== 1 ,  cluster(countryID) first

xtivreg2 rat1Esp (IMFprogram = IVLQR) IMFprob l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* ///
ttrend* ///
 if sample== 1, fe cluster(countryID) first 

xtivreg2 rat1Esp (IMFprogram = IVLQR) IMFprob l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if sample== 1, fd cluster(countryID) 

ivreg2 d2_rat1Esp (IMFagreement = IVLQR) IMFprob l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if sample== 1, cluster(countryID) first savefirst savefprefix(tabfirst16)




* for R2 comment  (interactive model):
 reg rat1Esp c.IMFprogram##c.lnIMFgrossliquidity  l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi countrydummies*  if sample== 1, cluster(countryID) 
 margins  , dydx(IMFprogram)  at(lnIMFgrossliquidity = (4.5(0.5)7.5))
 marginsplot , scheme(plotplain) yline(0, lcolor(cranberry)) xtitle("IMF liquidity") ytitle("Effect of IMF program on S&P Ratings") ylabel(-2(.5)0.5)
 graph export "output/FIGURE_FOR_R2.png", replace	

ivreg2 d2_rat1Esp (IMFagreement = IVLQR)  IMFprob   l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if sample== 1,  cluster(countryID) first savefirst savefprefix(tabfirst16)
 


 
 
 
 
 
 
* FIGURE 5: Coefficient Plot
	
gen InstInv5 = InstInv2 / 5 // to make comparable

gen d1_rat1Emoody 	= rat1Emoody - l.rat1Emoody
gen d1_rat1Efitch 	= rat1Efitch - l.rat1Efitch 
gen d1_rat1EII 		=  InstInv5 - l.InstInv5

cap est drop t*

reg rat1Esp IMFprogram  if sample== 1, cluster(countryID) //
est store t1s
reg rat1Emoody IMFprogram  if sample== 1, cluster(countryID) //
est store t1m
reg rat1Efitch IMFprogram  if sample== 1, cluster(countryID) //
est store t1f
reg InstInv5 IMFprogram  if sample== 1, cluster(countryID) //
est store t1i

xtreg rat1Esp IMFprogram  if sample== 1, fe cluster(countryID) //
est store t2s
xtreg rat1Emoody IMFprogram  if sample== 1, fe cluster(countryID) //
est store t2m
xtreg rat1Efitch IMFprogram  if sample== 1, fe cluster(countryID) //
est store t2f
xtreg InstInv5 IMFprogram  if sample== 1, fe cluster(countryID) //
est store t2i

xtreg rat1Esp IMFprogram  yeardummies* if sample== 1, fe cluster(countryID) //
est store t3s
xtreg rat1Emoody IMFprogram  yeardummies*   if sample== 1, fe cluster(countryID) //
est store t3m
xtreg rat1Efitch IMFprogram   yeardummies*  if sample== 1, fe cluster(countryID) //
est store t3f
xtreg InstInv5 IMFprogram   yeardummies*  if sample== 1, fe cluster(countryID) //
est store t3i

xtreg rat1Esp IMFprogram  l4.($control) yeardummies* if sample== 1, fe cluster(countryID) //
est store t4s
xtreg rat1Emoody IMFprogram  l4.($control) yeardummies*   if sample== 1, fe cluster(countryID) //
est store t4m
xtreg rat1Efitch IMFprogram   l4.($control) yeardummies*  if sample== 1, fe cluster(countryID) //
est store t4f
xtreg InstInv5 IMFprogram   l4.($control) yeardummies*  if sample== 1, fe cluster(countryID) //
est store t4i

rename IMFprogram IMFprogramreal 
rename d1_IMFprogram IMFprogram // this is done to make coefplot nicer

reg d1_rat1Esp IMFprogram d45X* yeardummies* if sample== 1,  cluster(countryID)
est store t5s
reg d1_rat1Emoody IMFprogram d45X* yeardummies* if sample== 1,  cluster(countryID)
est store t5m
reg d1_rat1Efitch IMFprogram d45X* yeardummies* if sample== 1,  cluster(countryID)
est store t5f
reg d1_rat1EII IMFprogram d45X* yeardummies* if sample== 1,  cluster(countryID)
est store t5i

rename IMFprogram d1_IMFprogram 
rename IMFprogramreal IMFprogram 


*rename IMFprogram IMFagreement
*rename IMFprogramreal IMFprogram

xtivreg2 rat1Esp (IMFprogram = IVLQR) l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob   yeardummies* if sample== 1, fe cluster(countryID) first savefirst savefprefix(tabfirst57sp)
est store t6s
xtivreg2 rat1Emoody (IMFprogram = IVLQR) l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  IMFprob   yeardummies* if sample== 1, fe cluster(countryID) first savefirst savefprefix(tabfirst57moody)
est store t6m
xtivreg2 rat1Efitch (IMFprogram = IVLQR) l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  IMFprob   yeardummies* if sample== 1, fe cluster(countryID) first savefirst savefprefix(tabfirst57fitch)
est store t6f
xtivreg2 InstInv5 (IMFprogram = IVLQR) l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob   yeardummies* if sample== 1, fe cluster(countryID) first savefirst savefprefix(tabfirst57ii)
est store t6i


coefplot (t1s, mcolor(red) msymbol(S) ciopts(lcolor(red)) label("S&P")) 	(t1m, mcolor(green) msymbol(S) ciopts(lcolor(green)) label("Moody's")) (t1f, mcolor(gold) msymbol(S) ciopts(lcolor(gold)) label("Fitch"))    (t1i, mcolor(blue) msymbol(S) ciopts(lcolor(blue)) label("Inst. Investor"))   ///
		(t2s, mcolor(red) msymbol(circle) ciopts(lcolor(red)) nokey) 		(t2m, mcolor(green) msymbol(circle) ciopts(lcolor(green))nokey) 		(t2f, mcolor(gold) msymbol(circle) ciopts(lcolor(gold))nokey)  (t2i, mcolor(blue) msymbol(circle) ciopts(lcolor(blue))nokey)   ///
		(t3s, mcolor(red) msymbol(circle_hollow) ciopts(lcolor(red))nokey) (t3m, mcolor(green) msymbol(circle_hollow) ciopts(lcolor(green))nokey) (t3f, mcolor(gold) msymbol(circle_hollow) ciopts(lcolor(gold))nokey)  (t3i, mcolor(blue) msymbol(circle_hollow) ciopts(lcolor(blue))nokey)   ///
		(t4s, mcolor(red) msymbol(D) ciopts(lcolor(red))nokey) 				(t4m, mcolor(green) msymbol(D) ciopts(lcolor(green))nokey) 				(t4f, mcolor(gold) msymbol(D) ciopts(lcolor(gold))nokey)    (t4i, mcolor(blue) msymbol(D) ciopts(lcolor(blue))nokey)   ///
		(t5s, mcolor(red)  msymbol(Dh) ciopts(lcolor(red))nokey) 						(t5m, msymbol(Dh) mcolor(green) ciopts(lcolor(green))nokey) 				(t5f, msymbol(Dh) mcolor(gold) ciopts(lcolor(gold))nokey)   (t5i, msymbol(Dh) mcolor(blue) ciopts(lcolor(blue))nokey)   ///
		(t6s, mcolor(red)  msymbol(T) ciopts(lcolor(red))nokey) 						(t6m, msymbol(T) mcolor(green) ciopts(lcolor(green))nokey) 				(t6f, msymbol(T) mcolor(gold) ciopts(lcolor(gold))nokey)   (t6i, msymbol(T) mcolor(blue) ciopts(lcolor(blue))nokey)   ///
			, keep(IMFprogram D.IMFprogram) level(90) vertical noeqlabels rename(IMFprogram = "-")   ///
			text(-8 0.6 "(1)" "OLS", size(small)) text(-3.3 0.77 "(2)" "OLS-FE", size(small)) text(-3.3 0.93 "(3)" "OLS-FE", size(small)) text(-3.3 1.09 "(4)" "OLS-FE", size(small)) text(-2.8 1.25 "(5)" "OLS-FD", size(small)) text(-0.8 1.41 "(6)" "IV", size(small))  ///
			scheme(plotplain) yline(0, lcolor(black)) yscale(range(-8(1)8)) ylabel(-8(4)8) xlabel(none)
			graph export "output/FIGURE6_COEFPLOT_BASELINE.png", replace
			
	

	

 
 
 
 
*TABLE 2: CHANNELS

lab var restructured_dummy "Debt restructuring"
cap est drop _all
foreach var in  gdp_growth  inflation2 ChangeGovDebtGDP cab restructured_dummy {
eststo `var': xtivreg2 `var' (IMFprogram = IVLQR) IMFprob l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi yeardummies* if sample == 1, fe cluster(countryID)  
}

estout _all using "output/Table3_channels.txt", title("Table - Channels") ///
 replace delimiter(_tab) label noabbrev style(tab) keep(IMFprogram   ) varlabel(IMFprogram "IMFprogram")  ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3)))  mlabel("GDP growth" "Inflation" "Change in Government Debt" "Current Account Balance" "Debt restructuring" ) ///
 stats(N idp widstat, fmt(0 3 3 3) ///
 label("Observations" "K-P underid. p" "K-P weak id. F")) 
 

estimates drop _all

foreach var in  gdp_growth  inflation2 ChangeGovDebtGDP cab restructured_dummy  {
eststo `var': xtivreg2 f1.`var' (IMFprogram = IVLQR) IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi yeardummies* if sample == 1, fe cluster(countryID)  
}

estout _all using "output/Table3_channels.txt", title("Table - Channels") ///
 append delimiter(_tab) label noabbrev style(tab) keep(IMFprogram   ) varlabel(IMFprogram "IMFprogram")  ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3)))  mlabel("GDP growth"  "Inflation" "Change in Government Debt" "Current Account Balance" "Debt restructuring") ///
 stats(N idp widstat, fmt(0 3 3 3) ///
 label("Observations" "K-P underid. p" "K-P weak id. F")) 
 
*discuss in text:
tab restructured_dummy IMFprogram // !
tab restructured_dummy IMFprogram if e(sample) // !
tab restructured_dummy IMFprogram if sample == 1 // !







 
*FIGURE 6: MONTHLY Rating Levels




use "processed/IMFRATINGMONTHLY2.dta", clear

/*
tostring _merge, replace force
replace _merge = "IMF data only" if _merge == "1"
replace _merge = "Rating data only" if _merge == "2"
replace _merge = "IMF and Rating Data" if _merge == "3"
rename _merge datasources


drop if year < 1990

replace IMFprogram = 0 if IMFprogram == .

bys country_code: egen totalIMFmonths = total(IMFprogram)

tab yearmonth

*gen fixed Effects
tab country_code, gen(countrydummies)
tab year, gen(yeardummies)
tab month, gen(monthdummies)
tab yearmonth, gen(yearmonthdummies)

egen countryID = group(country_code)
egen countryyearID = group(country_code year)

sort yearmonth
sort countryID year month
sort yearmonth
egen monthcount = group(yearmonth)
xtset countryID monthcount
sort countryID monthcount
***
by countryID : gen trend=[_n]
*country specific time-trends:
gen trend2 = trend^2
gen trend3 = trend^3
gen trend4 = trend^4

gen month2 = month^2 
gen month3 = month^3
gen month4 = month^4 

gen monthcount2 = monthcount^2 
gen monthcount3 = monthcount^3
gen monthcount4 = monthcount^4 

*country-year specific trend (cytrend):
sum countryyearID // max: = 1398
forvalues j=1(1)1398{
gen cytrend`j'=0
replace cytrend`j'=month if countryyearID==`j' 
}
xtset countryID monthcount
sort countryID monthcount
gen IMFstart = 0
replace IMFstart = 1 if IMFprogram == 1 & l.IMFprogram == 0 
tab IMFstart IMFapproval // 353 starts, 100 approvals without start (updated programs), 0 starts without approval

cap drop IMFend
gen IMFend = 0
replace IMFend = 1 if IMFprogram == 0 & l.IMFprogram == 1 // 322 ends

*test:
gen IMFstart2 = 0
replace IMFstart2 = 1 if IMFapproval ==  1 & l.IMFprogram == 0
tab IMFstart IMFstart2
drop IMFstart2 //test OK

bys country_code: egen cmean_rat1Esp = mean(rat1Esp_monthly)
gen devmean_rat1Esp = rat1Esp_monthly - cmean_rat1Esp

*code only first IMFprogram start
xtset countryID monthcount
sort countryID monthcount
bys countryID: gen sumIMFstart = sum(IMFstart)
gen firstIMFstart = IMFstart
replace firstIMFstart = 0 if sumIMFstart > 1
tab firstIMFstart // 122 first starts

gen monthsafterfirstIMFstart = 0
xtset countryID monthcount
sort countryID monthcount
quietly{
forvalues i = 1(1)324 {
replace monthsafterfirstIMFstart = `i' if l`i'.firstIMFstart == 1
}
forvalues i = 1(1)324 {
replace monthsafterfirstIMFstart = -`i' if f`i'.firstIMFstart == 1
}
}
bysort country_code year: egen totalIMFstarts_cy = total(IMFstart)
*/



xtset countryID monthcount
sort countryID monthcount

*no FE
reg rat1Esp f11.IMFstart f10.IMFstart f9.IMFstart f8.IMFstart f7.IMFstart f6.IMFstart f5.IMFstart f4.IMFstart f3.IMFstart f2.IMFstart f1.IMFstart IMFstart ///
			l.IMFstart l2.IMFstart l3.IMFstart l4.IMFstart l5.IMFstart l6.IMFstart l7.IMFstart l8.IMFstart l9.IMFstart l10.IMFstart l11.IMFstart ///
				, robust
est store tabm1


*country, year
reghdfe rat1Esp  f11.IMFstart f10.IMFstart f9.IMFstart f8.IMFstart f7.IMFstart f6.IMFstart f5.IMFstart f4.IMFstart f3.IMFstart f2.IMFstart f1.IMFstart IMFstart ///
				l.IMFstart l2.IMFstart l3.IMFstart l4.IMFstart l5.IMFstart l6.IMFstart l7.IMFstart l8.IMFstart l9.IMFstart l10.IMFstart l11.IMFstart  ///
				, absorb(countryID year) vce(robust)
est store tabm2

*countryXyear
reghdfe rat1Esp f11.IMFstart f10.IMFstart f9.IMFstart f8.IMFstart f7.IMFstart  f6.IMFstart f5.IMFstart f4.IMFstart f3.IMFstart f2.IMFstart f1.IMFstart IMFstart ///
				l.IMFstart l2.IMFstart l3.IMFstart l4.IMFstart l5.IMFstart l6.IMFstart  l7.IMFstart l8.IMFstart l9.IMFstart l10.IMFstart l11.IMFstart  ///
				, absorb(countryID#year) vce(robust)
est store tabm3


*countryXyear, month
reghdfe rat1Esp f11.IMFstart f10.IMFstart f9.IMFstart f8.IMFstart f7.IMFstart  f6.IMFstart f5.IMFstart f4.IMFstart f3.IMFstart f2.IMFstart f1.IMFstart IMFstart ///
				l.IMFstart l2.IMFstart l3.IMFstart l4.IMFstart l5.IMFstart l6.IMFstart  l7.IMFstart l8.IMFstart l9.IMFstart l10.IMFstart l11.IMFstart  ///
				, absorb(countryID#year monthcount) vce(robust)
est store tabm4

*COEFPLOT	
	*labels
	quietly{
	forvalues i = 1(1)11 {
	cap gen f`i'_IMFstart = f`i'.IMFstart
	label var f`i'_IMFstart "-`i'"			
	cap gen l`i'_IMFstart = l`i'.IMFstart
	label var l`i'_IMFstart "`i'"			
	}
	}
	label var IMFstart "0"

reghdfe rat1Esp f11_IMFstart f10_IMFstart f9_IMFstart f8_IMFstart f7_IMFstart  f6_IMFstart f5_IMFstart f4_IMFstart f3_IMFstart f2_IMFstart f1_IMFstart IMFstart ///
				l1_IMFstart l2_IMFstart l3_IMFstart l4_IMFstart l5_IMFstart l6_IMFstart  l7_IMFstart l8_IMFstart l9_IMFstart l10_IMFstart l11_IMFstart  ///
				, absorb(countryID#year monthcount) vce(robust)
est store tabm4
			coefplot tabm4, drop(_cons) vertical ///
			xlabel(, labsize(medsmall) angle(horizontal) ) ///
			ylabel(, labsize(medsmall)) ///
					graphregion(color(white))  mcolor(black) msymbol(O) ///
								   xtitle("IMF agreement, leads / lags of x months         " , color(black) size(medium) margin(medium)) yline(0, lcolor(cranberry)) ///
								   ytitle("Effect on rating in month m", color(black) size(medium)) ylabel(,nogrid) xline(12, lcolor(cranberry)) ///
								title("", color(black) size(medium)) ///
								yscale(range(-0.5 0.5)) ciopts(lcolor(black)) ///
								xsize(6) ysize(4) level(90) ///
								xlabel(1 "-11" 3 "-9" 6 "-6" 9 "-3" 12 "0" 15 "+3" 18 "+6" 21 "+9" 23 "+11") ///
								ylabel(0 "0" -.5 "-.5" 0.5 ".5") ///
								scheme(plotplain)
								graph export "output/FIGURE6_coefplot_monthly.png", replace width(3000) height(2000)

	
	
	
								
*FIGURE 7: MONTHLY Rating Changes

xtset countryID monthcount
sort countryID monthcount	

mat A=J(22,2,0)

local no = 1
reghdfe S11.rat1Esp  	IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1				
reghdfe S10.rat1Esp  	IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S9.rat1Esp   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S8.rat1Esp   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S7.rat1Esp   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S6.rat1Esp   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S5.rat1Esp   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S4.rat1Esp   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe S3.rat1Esp   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe S2.rat1Esp   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe S1.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe f1.S1.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1		
reghdfe f2.S2.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
					
reghdfe f3.S3.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe f4.S4.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f5.S5.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f6.S6.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f7.S7.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f8.S8.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f9.S9.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)					
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f10.S10.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)						
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'					
local no = `no'+1
reghdfe f11.S11.rat1Esp  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)						
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'		

coefplot matrix(A[,1]), se(A[,2]) xtitle("months (m) before / after IMF agreement" , color(black) margin(medium)) levels(90) ciopts(lcolor(black)) ///
ytitle("Effect of IMF agreement "  "on rating in month x" , color(black) margin(medium)) ///
yline(0, lcolor(cranberry)) xline(11.5, lcolor(cranberry)) vertical graphregion(color(white)) ///
mcolor(black) xsize(6) ysize(4) xlabel(1 "-11" 3 "-9" 6 "-6" 9 "-3" 11.5 "m" 14 "+3" 17 "+6" 20 "+9" 22 "+11")  ylabel(,nogrid angle(0)) ///
scheme(plotplain) msymbol(O) ///
ylabel(, labsize(medmall)) xlabel(, labsize(medsmall))
graph export "output/FIGURE7_coefplot_monthly_difference_rating.png", replace width(3000) height(2000)









 
 
*Figure 8: NEGOTIATIONS
 
 
use "processed/IMFRATINGMONTHLY2", clear

tab country_code, gen(countrydummies)
tab year, gen(yeardummies)
tab month, gen(monthdummies)
tab yearmonth, gen(yearmonthdummies)

xtset countryID monthcount
sort countryID monthcount
***
by countryID : gen trend=[_n]
*country specific time-trends:
gen trend2 = trend^2
gen trend3 = trend^3
gen trend4 = trend^4

gen month2 = month^2 
gen month3 = month^3
gen month4 = month^4 

gen monthcount2 = monthcount^2 
gen monthcount3 = monthcount^3
gen monthcount4 = monthcount^4 

/*
*country-year specific trend (cytrend):
sum countryyearID // max: = 1398
forvalues j=1(1)1398{
gen cytrend`j'=0
replace cytrend`j'=month if countryyearID==`j' 
}
*/
xtset countryID monthcount
sort countryID monthcount
sum  time_neg_to_start

xtset countryID monthcount
sort countryID monthcount	
 label var negotiation_begin "Begin negotiation"
 
 
	gen monthsafterIMFstart_absolute= monthsafterIMFstart
	replace monthsafterIMFstart_absolute=  -1* monthsafterIMFstart if monthsafterIMFstart<0
	
	gen monthsafternegotiation_begin_abs= monthsafternegotiation_begin
	replace monthsafternegotiation_begin_abs=  -1* monthsafternegotiation_begin if monthsafternegotiation_begin<0
 
 
 *regression for coefplot
		reghdfe rat1Esp_monthly     /// 
		f8.negotiation_begin f7.negotiation_begin f6.negotiation_begin  f5.negotiation_begin f4.negotiation_begin f3.negotiation_begin f2.negotiation_begin f1.negotiation_begin negotiation_begin ///
				l.negotiation_begin l2.negotiation_begin l3.negotiation_begin l4.negotiation_begin l5.negotiation_begin l6.negotiation_begin  l7.negotiation_begin l8.negotiation_begin l9.negotiation_begin l10.negotiation_begin     ///
				l11.negotiation_begin l12.negotiation_begin l13.negotiation_begin  ///
				 if  no_nego_info ==.   , ///
				absorb(countryID#year monthcount ) vce(robust)
est store tabm6
			coefplot tabm6, drop(_cons) vertical xlabel(, labsize(medium) angle(horizontal) ) ///
					graphregion(color(white))  bgcolor(white) mcolor(black) ///
								   xtitle("IMF negotiation, leads / lags of x months          " , color(black) size(medium) margin(medium)) yline(0, lcolor(cranberry) lpattern(dash)) ///
								   ytitle("Effect on rating in month m", color(black) size(medium)) ylabel(,nogrid) xline(9, lcolor(cranberry) lpattern(dash)) ///
								title("", color(black) size(medium)) ///
								yscale(range(-0.5 0.5)) ciopts(lcolor(black)) ///
								xsize(6) ysize(4) level(90) xlabel( 3 "-6" 6 "-3" 9 "0" 12 "3" 15 "6" 18 "9" 21 "12") ///
								ylabel(0 "0" -.5 "-0.5" 0.5 ".5")	///
								xline(13.5, lcolor(navy))  text(0.49 11.5   "On average IMF program" "starts 4.3 months later", box place(e) )
				graph export "graphs/FIGURE8_coefplot_monthly_cyfe_mfe_nego.png", replace width(3000) height(2000)
				
				
				
*TABLE 3: comparing negotiation and early program period.			
	lab var IMFprogram	"IMF program"
	reg rat1Esp_monthly IMFprogram if 	(neg_but_no_agreement==1 )  | ///
		(monthsafterIMFstart<=12   & monthsafterIMFstart>=0) , robust
	est store tabm7
	estadd local sample "negotiation period & first program year"
	
	estout tabm7 using "output/Table3_negotiations.txt", title("") ///
 replace  delimiter(_tab) label noabbrev style(tab) collabels(none) /// 
 keep(IMFprogram) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
 stats(N sample, fmt(0 0) ///
 label("Observations" "Months in sample"))  ///
 mlabel("(1)")

		*as coefplot:
			coefplot tabm7, drop(_cons) vertical xlabel(none) ///
					graphregion(color(white))  mcolor(black) ///
								   xtitle("Effect of IMF Program relative to negoation period" , color(black) size(medium) margin(medium)) yline(0, lcolor(orange)) ///
								   ytitle("Effect on rating", color(black) size(medium)) ylabel(,nogrid) xline(9, lcolor(orange)) ///
								title("", color(black) size(medium)) ///
								yscale(range(-0.2 0.5)) ciopts(lcolor(black)) level(90) ///
								ylabel(0 "0" -.2 "-0.2" 0.2 ".2" 0.4 "0.4")
			graph export "graphs/coefplot_monthly_start_vs_nego.png", replace width(3000) height(2000)
								
			
		sum rat1Esp_monthly if neg_but_no_agreement==1  	
		sum rat1Esp_monthly if (monthsafterIMFstart<=12   & monthsafterIMFstart>=0) 
	
	
*The histogram for the Appendix:
 sum time_neg_to_start
   hist time_neg_to_start , ///
graphregion(color(white))  mcolor(black)  percent fcolor(orange) lcolor(black)  ///
 xtitle("Months between begin of negotiations and IMF program begin" , color(black) size(medium) margin(medium))  ///
 xline(3,  lpattern( dash )) text(17 5   "On average IMF program" "starts 4.3 months later", box place(e) )
 graph export "graphs/hist_nego.png", replace width(3000) height(2000)
 
 
 
 
 



*FIGURE 9: TEXT ANALYSIS

import excel "Text analysis/IMF_text_17Oct2018.xlsx", firstrow clear

drop if text == ""

gen noliq_noref = 0
replace noliq_noref = 1 if liquidity_only == 0 & reform_only == 0 & liq_and_ref == 0

gen test = liquidity_only + reform_only + liq_and_ref + noliq_noref

tab positive if no_info != 1

gen neutral = 0
replace neutral = 1 if positive == 0 & negative == 0

replace expect = 0 if expect == .

gen reformmentioned = 0
replace reformmentioned = 1 if reform_only == 1 | liq_and_ref == 1 

gen category = 1 if liquidity_only==1
replace category = 2 if reform_only==1
replace category = 3 if liq_and_ref==1
replace category = 4 if noliq_noref == 1

tab category, sum(positive) // use these values for text option below

graph hbar (sum) positive neutral negative, over(category, ///
	relabel(1 "Liquidity" 2 "Reforms" 3 "Liquidity and Reforms" 4 "Residual Category") label(labsize(medsmall))) ///
	stack ///
	yvaroptions(relabel(1 "Positive association with rating"  2 "No clear association with rating" 3 "Negative association with rating" )) ///
	ytitle("Number of statements") graphregion(color(white) lwidth(large)) ///
	ylabel(,nogrid labsize(medsmall)) legend(cols(1)) bar(1, color(70 204 80)) bar(2,color(255 255 80)) bar(3,color(204 0 0 )) lintensity(255) ///
	text(6 89 "67%") text(11 63.5 "95%") text(12.5 38 "89%") text(14 12.5 "54%") ///
	scheme(plotplain) legend(pos(6) size(medsmall)) 
	
graph export "output/FIGURE9_textanalysis.png" , as(png) replace
	

	
	
	

	
	



*FIGURE 10: Year-on-year variation in FIRST STAGE: LEADS AND LAGS

use  "processed/IMFRATING2",clear
sort countryID year
xtreg IMFprogram yeardummies*  c.lnIMFgrossliquidity##c.IMFprob  c.f2.lnIMFgrossliquidity##c.IMFprob   c.f.lnIMFgrossliquidity##c.IMFprob  c.l2.lnIMFgrossliquidity##c.IMFprob c.l.lnIMFgrossliquidity##c.IMFprob l1.IMFprob l2.IMFprob , fe cluster(country_ID)

regsave cL2.lnIMFgrossliquidity#c.IMFprob cL.lnIMFgrossliquidity#c.IMFprob  c.lnIMFgrossliquidity#c.IMFprob cF.lnIMFgrossliquidity#c.IMFprob cF2.lnIMFgrossliquidity#c.IMFprob  , ci level(90)
gen count=[_n]
gen Number=1
replace Number=2 if count==5
replace Number=3 if count==1
replace Number=4 if count==3
replace Number=5 if count==2

cap label define cat 1 "t-2" 2 "t-1" 3 "t" 4 "t+1" 5 "t+2" 
cap label values Number cat
sort  Number

twoway   (line ci_lower Number, lwidth(vthin) color(gs10)  xline(6) ytick(-0.01  0 0.01, gstyle(major)) bgcolor(white) graphregion(color(white)) ) ///
(line ci_upper Number, lwidth(vthin)  color(gs10) ) (rcap ci_upper ci_lower Number, lwidth(medium) msize(vlarge) color(black)) ///
(line coef Number, lwidth(medthin) lpattern(dash) color(black)) ///
(scatter coef Number,  msymbol( square  ) msize(medlarge) color(cranberry)), ///
		yline(0, lwidth( medsmall ) lcolor(black) )   legend(off) ///
		xlabel(1(1)5, valuelabel) xmtick(1(1)5) ///
		xtitle("IMF Liquidity in t-2 to t+2", margin(medsmall)) yscale(lwidth(medium)) xscale(lwidth(medium)) ///
		yscale(range(-0.15 0.1)) ylabel(,  angle(0)) ytitle(Coefficient for IMF probability(t) x IMF liquidity, margin(none))
		
 graph export "output/FIGURE10_FIRSTSTAGELEADLAG.png",width(4000) replace


 
 
 
 
 

 
 
 
*FIGURE 11: ROBUSTNESS COEFPLOT
 
use "processed/IMFRATING2.dta", clear

gen InstInv5 = InstInv2 / 5 // to make comparable

gen  rat1Eii = InstInv5

egen IMFnoPRGF = rowmax(SBA5_dummy EFF5_dummy SAF5_dummy)
tab IMFprogram IMFnoPRGF

sort countryID year
bysort countryID: gen IMFnoPRGFprob = sum(IMFnoPRGF) / (year - 1972)
gen IVLQR_noPRGF = lnIMFgrossliquidity * IMFnoPRGFprob

	 global control		ln_gdp_pc_const gdp_growth inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

		

cap est drop tab4*
cap est drop tabf4*

xtivreg2 rat1Esp (IMFprogram = IVLQR)  IMFprob l4.($control)  yeardummies*, fe cluster(countryID) 
gen sample = 1 if e(sample)

*IV global cycle controls
cap drop IVgrowth IVcrises IVgrowthhic IVfdi
gen IVgrowth = IMFprob * worldGDPgrowth
gen IVcrises = IMFprob * crises_LV // ! 
*gen IVgrowthhic = IMFprob * g1_totalgdphic
gen IVfdi = IMFprob * d1_fdiin2gdp_hic

*All other controls times liquidity as controls
	sort countryID year
	foreach var of varlist $control {
	gen `var'Xliquid = `var' * lnIMFgrossliquidity
	gen l4_`var'Xliquid = l4.`var'Xliquid
	}
	


foreach agency in sp fitch moody ii {

*Column 1: IMFnn - one month active
rename IMFprogram IMFprogramreal
rename IMFnn IMFprogram
xtivreg2 rat1E`agency' (IMFprogram = IVLQR) l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi  IMFprob   yeardummies* if sample== 1, fe cluster(countryID) first savefirst savefprefix(tabf41`agency')
est store tab41`agency'
rename IMFprogram IMFnn 
rename IMFprogramreal IMFprogram 

*Column 2: no PRGF
rename IMFprogram IMFprogramreal
rename IMFnoPRGF IMFprogram

xtivreg2 rat1E`agency' (IMFprogram = IVLQR) l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi   IMFprob   yeardummies* if sample== 1, fe cluster(countryID) first savefirst savefprefix(tabf42`agency')
est store tab42`agency'
rename IMFprogram IMFnoPRGF 
rename IMFprogramreal IMFprogram 


*Column 3: IMF agreements
preserve
replace IMFprogram = IMFagreement
xtivreg2 rat1E`agency' (IMFprogram = IVLQR) IMFprob  l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi   yeardummies* if sample==1, fe cluster(countryID) first savefirst savefprefix(tabf43`agency')
est store tab43`agency'
restore

*Column 4: Exclude Eurozone
xtivreg2 rat1E`agency'  (IMFprogram = IVLQR) IMFprob    l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if DEuro != 1 & sample==1, fe cluster(countryID) first savefirst savefprefix(tabf44`agency')
est store tab44`agency'

*Column 5: constant probability
xtivreg2 rat1E`agency' (IMFprogram = IVLQRc)    l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if sample==1, fe cluster(countryID) first savefirst savefprefix(tabf45`agency')
est store tab45`agency'

*Column 6: Exclude observations with large repurchases
xtivreg2 rat1E`agency' (IMFprogram = IVLQR) IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi yeardummies* if top5IMFpur!=1 & sample==1, fe cluster(countryID) first savefirst savefprefix(tabf46`agency')
est store tab46`agency'
}



coefplot  (tab41sp, mcolor(red) msymbol(circle) ciopts(lcolor(red)) nokey) 		(tab41fitch, mcolor(green) msymbol(circle) ciopts(lcolor(green))nokey)		 	(tab41moody, mcolor(gold) msymbol(circle) ciopts(lcolor(gold))nokey)  	/*	(tab42_NOUS, mcolor(green) msymbol(circle) ciopts(lcolor(green))nokey)  */  (tab41ii, mcolor(blue) msymbol(circle) ciopts(lcolor(blue))nokey)   ///
		 || (tab42sp, mcolor(red) msymbol(circle_hollow) ciopts(lcolor(red))nokey) (tab42fitch, mcolor(green) msymbol(circle_hollow) ciopts(lcolor(green))nokey) (tab42moody, mcolor(gold) msymbol(circle_hollow) ciopts(lcolor(gold))nokey)  /* (tab43_NOUS, mcolor(green) msymbol(circle_hollow) ciopts(lcolor(green))nokey) */ (tab42ii, mcolor(blue) msymbol(circle_hollow) ciopts(lcolor(blue))nokey)   /// || (tab43sp, mcolor(red) msymbol(D) ciopts(lcolor(red))nokey)			 (tab43fitch, mcolor(green) msymbol(D) ciopts(lcolor(green))nokey) 				(tab43moody, mcolor(gold) msymbol(D) ciopts(lcolor(gold))nokey)  			/*(tab44_NOUS, mcolor(green) msymbol(D) ciopts(lcolor(green))nokey) 			*/	 (tab43ii, mcolor(blue) msymbol(D) ciopts(lcolor(blue))nokey)   ///
		|| (tab44sp, mcolor(red) msymbol(Dh)  ciopts(lcolor(red))nokey) 					(tab44fitch, mcolor(green) msymbol(Dh) ciopts(lcolor(green))nokey) 								(tab44moody, mcolor(gold) msymbol(Dh) ciopts(lcolor(gold))nokey)  					/* (tab45_NOUS, mcolor(green) ciopts(lcolor(green))nokey)  				*/	(tab44ii, mcolor(blue) msymbol(Dh) ciopts(lcolor(blue))nokey)   ///
		|| (tab45sp, mcolor(red) msymbol(T) ciopts(lcolor(red)) label("S&P")) 	(tab45fitch, mcolor(green) msymbol(T) ciopts(lcolor(green)) label("Moody's")) (tab45moody, mcolor(gold) msymbol(T) ciopts(lcolor(gold)) label("Fitch"))  /* (tab41_NOUS, mcolor(green) msymbol(T) ciopts(lcolor(green)) label("Non-US")) */   (tab45ii, mcolor(blue) msymbol(T) ciopts(lcolor(blue)) label("Inst. Investor"))    /// 
		|| (tab46sp, mcolor(red) msymbol(S)  ciopts(lcolor(red))nokey) 					(tab46fitch, mcolor(green) msymbol(S) ciopts(lcolor(green))nokey) 								(tab46moody, mcolor(gold)  msymbol(S) ciopts(lcolor(gold))nokey)  					/* (tab45_NOUS, mcolor(green) ciopts(lcolor(green))nokey)  				*/	(tab46ii, mcolor(blue) msymbol(S) ciopts(lcolor(blue))nokey)    ///
		, keep(IMFprogram) level(90) vertical noeqlabels rename(IMFprogram = "_") ///
			yscale(range(-2 10)) ylabel(-2 (2) 8)  ///
			yline(0) ///
			scheme(plotplain) // legend(order(1 "S&P" 2 "Fitch" 3 "Moody's'" 4 "Inst. Investor")) 
			
	gr_edit	.plotregion1.subtitle[1].text = {}
	gr_edit	.plotregion1.subtitle[1].text.Arrpush "1) IMF programs one month active"
	gr_edit	.plotregion1.subtitle[2].text = {}
	gr_edit	.plotregion1.subtitle[2].text.Arrpush "2) IMF programs other than PRGF"
	*gr_edit	.plotregion1.subtitle[3].text = {}
	*gr_edit	.plotregion1.subtitle[3].text.Arrpush "3) IMF agreements"
	gr_edit	.plotregion1.subtitle[3].text = {}
	gr_edit	.plotregion1.subtitle[3].text.Arrpush "3) exluding Eurozone" 
	gr_edit	.plotregion1.subtitle[4].text = {}
	gr_edit	.plotregion1.subtitle[4].text.Arrpush "4) constant IMFprobability"
	gr_edit	.plotregion1.subtitle[5].text = {}
	gr_edit	.plotregion1.subtitle[5].text.Arrpush "5) exluding large repurchases"
		
		graph export "output/FIGURE10_COEFPLOTROBUST.png", replace
		
					
lab var IMFprogram "IMF program"		
estout tab4*sp  using "Tables/TableA6_VARIOUS_ROBUSTNESS.txt", title("Various Robustness Tests") ///
 replace delimiter(_tab) label noabbrev style(tab)  ///
 collabels(none) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
  keep(IMFprogram) order(IMFprogram)  ///
 mlabel("IMF programs one month active"  "IMF programs other than PRGF" "IMF agreements" "excluding Eurozone" "constant IMF probability"  "excluding large repurchases")  ///
 stats(N  idp widstat, fmt(0 3 3) ///
 label("Observations" "KP underid. (p)" "KP weak id. (F)"))
 
  estout tabf4*sp* using "Tables/TableA6_VARIOUS_ROBUSTNESS.txt",  ///
   collabels(none) ///
 append delimiter(_tab) label noabbrev style(tab) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
  keep(IMFprob IVLQR IVLQRc) order(IMFprob IVLQR IVLQRc)  mlabel(none)
 
 
 
 
 
 
 
 
 
 
 
 
	
******************************************************************************
*APPENDICES
******************************************************************************




*Appendix E: RATING TRENDS AROUND IMF STARTS - ONE YEAR +/-


use "processed/IMFRATINGMONTHLY2", clear


xtset countryID monthcount
sort countryID monthcount

bysort monthsafterfirstIMFstart: egen mean_meandevrating = mean(devmean_rat1Esp) if totalIMFmonths != 0


twoway line mean_meandevrating monthsafterfirstIMFstart if -12 < monthsafterfirstIMFstart & monthsafterfirstIMFstart < 12 & totalIMFmonths != 0 ///
, graphregion(color(white)) bgcolor(white) ///
color(black) ///
xtitle("Months before/after start of first IMF program") ///
ytitle("Deviation from average country rating") ///
ylabel(, angle(0) ) ///
xline(0, lpattern(dash) lcolor(cranberry)) 
graph export "output/FIGUREA1_TREND_SHORT.png", replace






 

 
 
* Appendix F: DESCRIPTIVES TABLE
 use  "processed/IMFRATING2.dta",clear

  global control		ln_gdp_pc_const gdp_growth2 inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

gen InstInv5 = InstInv2 / 5 
					
lab var rat1Esp "Rating S&P"
lab var rat1Emoody "Rating Moody's"
lab var rat1Efitch "Rating Fitch"
lab var InstInv5 "Institutional Investor"
lab var IMFprogram "IMF program"
lab var IMFagreement "IMF agreement"
lab var IMFprob "IMF probability"
lab var ln_gdp_pc_const "GDP/capita (ln)"
lab var gdp_growth2 "GDP growth"
lab var inflation2 "Inflation"
lab var natresources "Natural resource rents (% GDP)"
lab var populationln "Population (ln)"
lab var DebtGDP "Debt (% GDP)"
lab var ChangeGovDebtGDP "Change in Government Debt (% GDP)"
lab var Ddefault "Default history (indicator)"
lab var default5 "Default in last 5 years (indicator)"
lab var openness "Trade openness"
lab var cab "Current Account Balance (% GDP)"
lab var extdebtgdp0 "External Debt (% GDP)"
lab var DEuro "Euro area (indicator)"
lab var LawOrder "Law and Order"
lab var polity2 "Democracy (Polity IV)"
lab var election "Election"
lab var honeymoon "Honeymoon"
lab var left "Left government"
lab var InternalConflict "Absence of Internal Conflict (ICRG)"
lab var ExternalConflict "Absence of External Conflict (ICRG)"
lab var MilitaryPolL "Absence of military in politics"
lab var investment "Investment (% GDP)"
lab var crisis_LV "Systemic Banking Crisis"
lab var bankexp_fi "Foreign bank exposure"
lab var idealpointUS "UNGA voting"
lab var worldGDPgrowth "Global GDP growth"
lab var crises_LV "Global total of Systemic Banking Crises" 
lab var KOF_fdi_st_gdp "FDI stock (% GDP)"
lab var bondspread_last_yearly "Bond yield spread (relative to US)"
	
xtivreg2 rat1sp (IMFprogram = IVLQR) IMFprob l4.($control) yeardummies*, fe cluster(countryID) 
cap drop sample
gen sample = 1 if e(sample)

 
estpost summarize  rat1Esp rat1Emoody rat1Efitch  InstInv5 IMFprogram IMFagreement IMFprob $control worldGDPgrowth crises_LV KOF_fdi_st_gdp bondspread_last_yearly if sample == 1 // to view on screen
 noisily esttab . using "output/DESCRIPTIVES.txt", cells("Variable (`e(labels)') mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") noobs tab label replace // for export 


 
 
 
 

 use  "processed/IMFRATING2.dta",clear

  global control		ln_gdp_pc_const gdp_growth inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

cap drop l4_*
foreach var of varlist $control {
	gen l4_`var' = l4.`var'
}



lab var l4_ln_gdp_pc_const "GDP/capita (ln)"
lab var l4_gdp_growth "GDP growth"
lab var l4_inflation2 "Inflation"
lab var l4_natresources "Natural resource rents (% GDP)"
lab var l4_populationln "Population (ln)"
lab var l4_DebtGDP "Debt (% GDP)"
lab var l4_ChangeGovDebtGDP "Change in Government Debt (% GDP)"
lab var l4_Ddefault "Default history (indicator)"
lab var l4_default5 "Default in last 5 years (indicator)"
lab var l4_openness "Trade openness"
lab var l4_cab "Current Account Balance (% GDP)"
lab var l4_extdebtgdp0 "External Debt (% GDP)"
lab var l4_DEuro "Euro area (indicator)"
lab var l4_LawOrder "Law and Order"
lab var l4_polity2 "Democracy (Polity IV)"
lab var l4_election "Election"
lab var l4_honeymoon "Honeymoon"
lab var l4_left "Left government"
lab var l4_InternalConflict "Absence of Internal Conflict (ICRG)"
lab var l4_ExternalConflict "Absence of External Conflict (ICRG)"
lab var l4_MilitaryPolL "Absence of military in politics"
lab var l4_investment "Investment (% GDP)"
lab var l4_crisis_LV "Systemic Banking Crisis"
lab var l4_bankexp_fi "Foreign bank exposure"
lab var l4_idealpointUS "UNGA voting"


xtivreg2 rat1sp (IMFprogram = IVLQR) IMFprob l4.($control) yeardummies*, fe cluster(countryID) 
cap drop sample1
gen sample = 1 if e(sample)
  
  
	*Table 1 Column 4: controls
xtivreg2 rat1Esp IMFprogram  l4_*  yeardummies* if sample== 1, fe cluster(countryID)
est store tabg
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"


estout tabg using "output/TableG_controls.txt", title("Controls") ///
 replace  delimiter(_tab) label noabbrev style(tab) collabels(none) /// 
 drop(yeardummies*) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3))) ///
 stats(CountryFE YearFE N r2 , fmt(0 0 0 3) ///
 label("Country FE" "Year FE"  "Observations" "Adjusted R-squared")) 

  
  
  
  
  
 *APPENDIX G: ROBUSTNESS 
  

  
* Table A6: VARIOUS ROBUSTNESS TESTS

*see regressions and table below coefplot above










*TABLE A7 - EXCLUDING OUTLIERS

use  "processed/IMFRATING2", clear 

 global control		ln_gdp_pc_const gdp_growth inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

					
	cap drop sample
	xtivreg2 rat1Esp (IMFprogram = IVLQR)  IMFprob l4.($control)  yeardummies*, fe cluster(countryID) 
	gen sample = 1 if e(sample)

	*gen IV
	cap drop IVLQR
	gen IVLQR = IMFprob * lnIMFgrossliquidity

	*IV global cycle controls
	cap drop IVgrowth IVcrises IVgrowthhic IVfdi
	gen IVgrowth = IMFprob * worldGDPgrowth
	gen IVcrises = IMFprob * crises_LV 
	gen IVfdi = IMFprob * d1_fdiin2gdp_hic

	*All other controls times liquidity as controls
	sort countryID year
	foreach var of varlist $control {
	gen `var'Xliquid = `var' * lnIMFgrossliquidity
	gen l4_`var'Xliquid = l4.`var'Xliquid
	}
	
	
cap est drop t2*

*outliers:
foreach agency in sp /*fitch moody ii */ {

*baseline
xtivreg2 rat1E`agency' (IMFprogram = IVLQR)  IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if sample == 1, fe cluster(countryID) first savefirst savefprefix(tabfirst17)
est store t20`agency'

*1st
reg IMFprogram IVLQR IMFprob  l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi    yeardummies* i.countryID if sample==1
cap drop _dfbeta*
dfbeta IVLQR
cap drop low high
egen low = pctile(_dfbeta) , p(1)
egen high = pctile(_dfbeta) , p(99)
xtivreg2 rat1E`agency' (IMFprogram = IVLQR)  IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if sample == 1 &  low < _dfbeta_1 &  _dfbeta_1 < high   , fe cluster(countryID) first
est store t21`agency'

reg IMFprogram IVLQR IMFprob  l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi    yeardummies* i.countryID if sample==1
cap drop _dfbeta*
dfbeta IVLQR
cap drop low high
egen low = pctile(_dfbeta) , p(5)
egen high = pctile(_dfbeta) , p(95)
xtivreg2 rat1E`agency' (IMFprogram = IVLQR)  IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi   yeardummies* if sample == 1 &  low < _dfbeta_1 &  _dfbeta_1 < high   , fe cluster(countryID) first
est store t22`agency'

*2nd
reg IMFprogram IVLQR IMFprob  l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi   yeardummies* i.countryID if sample==1
cap drop IMFhat
predict IMFhat, xb
reg rat1E`agency' IMFhat IMFprob  l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi   yeardummies* i.countryID  if sample==1
*avplot IMFhat, mlabel(countryyear)
cap drop _dfbeta*
dfbeta IMFhat
cap drop low high
egen low = pctile(_dfbeta) , p(1)
egen high = pctile(_dfbeta) , p(99)
xtivreg2 rat1E`agency' (IMFprogram = IVLQR)  IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi   yeardummies* if sample == 1 &  low < _dfbeta_1 &  _dfbeta_1 < high   , fe cluster(countryID) first
est store t23`agency'

reg IMFprogram IVLQR IMFprob  l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi   yeardummies* i.countryID if sample==1
cap drop IMFhat
predict IMFhat, xb
reg rat1E`agency' IMFhat IMFprob  l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi   yeardummies* i.countryID  if sample==1
*avplot IMFhat, mlabel(countryyear)
cap drop _dfbeta*
dfbeta IMFhat
cap drop low high
egen low = pctile(_dfbeta) , p(5)
egen high = pctile(_dfbeta) , p(95)
xtivreg2 rat1E`agency' (IMFprogram = IVLQR)  IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  yeardummies* if sample == 1 &  low < _dfbeta_1 &  _dfbeta_1 < high   , fe cluster(countryID) first
est store t24`agency'

}

estout t2*  using "output/TableA7_outliers.txt", title("Table 2 - Outliers") ///
 replace delimiter(_tab) label noabbrev style(tab)  ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
  keep(IMFprogram) order(IMFprogram)  ///
   stats(N idp widstat, fmt(0 3 3) ///
 label("N" "KP underid. (p)" "KP weak id. (F)"))
 
 
 

 
 
 




* TABLE A8: ALTERNATIVE CODING OF RATINGS

use  "processed/IMFRATING2", clear 

 global control		ln_gdp_pc_const gdp_growth inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

					
	cap drop sample
	xtivreg2 rat1Esp (IMFprogram = IVLQR)  IMFprob l4.($control)  yeardummies*, fe cluster(countryID) 
	gen sample = 1 if e(sample)

	*gen IV
	cap drop IVLQR
	gen IVLQR = IMFprob * lnIMFgrossliquidity

	*IV global cycle controls
	cap drop IVgrowth IVcrises IVgrowthhic IVfdi
	gen IVgrowth = IMFprob * worldGDPgrowth
	gen IVcrises = IMFprob * crises_LV 
	gen IVfdi = IMFprob * d1_fdiin2gdp_hic

	*All other controls times liquidity as controls
	sort countryID year
	foreach var of varlist $control {
	gen `var'Xliquid = `var' * lnIMFgrossliquidity
	gen l4_`var'Xliquid = l4.`var'Xliquid
	}

*1.) Recode S&P Rating
codebook rat1Esp
hist rat1Esp
hist rat1Esp if neverIMF==1


cap drop rat1Esp_alt1
gen rat1Esp_alt1=.
replace rat1Esp_alt1=1 if rat1Esp<=3 
replace rat1Esp_alt1=2 if rat1Esp>3 & rat1Esp<=5
replace rat1Esp_alt1=3 if rat1Esp>5  & rat1Esp<=7
replace rat1Esp_alt1=4 if rat1Esp>7  & rat1Esp<=9
replace rat1Esp_alt1=5 if rat1Esp>9 & rat1Esp<=11
replace rat1Esp_alt1=6 if rat1Esp>11 & rat1Esp<=13
replace rat1Esp_alt1=7 if rat1Esp>13 & rat1Esp<=15
replace rat1Esp_alt1=8 if rat1Esp>15 & rat1Esp<=17
replace rat1Esp_alt1=9 if rat1Esp>17 & rat1Esp<=19
replace rat1Esp_alt1=10 if rat1Esp>19  & rat1Esp!=.
hist rat1Esp_alt1 

cap drop rat1Esp_alt2
gen rat1Esp_alt2=.
replace rat1Esp_alt2=1 if rat1Esp<=5 
replace rat1Esp_alt2=2 if rat1Esp>5  & rat1Esp<=8
replace rat1Esp_alt2=3 if rat1Esp>8  & rat1Esp<=11
replace rat1Esp_alt2=4 if rat1Esp>11  & rat1Esp<=14
replace rat1Esp_alt2=5 if rat1Esp>14 & rat1Esp<=17
replace rat1Esp_alt2=6 if rat1Esp>17 & rat1Esp<=19
replace rat1Esp_alt2=7 if rat1Esp>19  & rat1Esp!=.
hist rat1Esp_alt2 


cap drop rat1Esp_alt3
gen rat1Esp_alt3=.
replace rat1Esp_alt3=0 if rat1Esp<=13 //BBB
replace rat1Esp_alt3=1 if rat1Esp>13  & rat1Esp!=.
hist rat1Esp_alt3 

cap drop rat1Esp_alt4
gen rat1Esp_alt4=.
replace rat1Esp_alt4=0 if rat1Esp<=16 //A
replace rat1Esp_alt4=1 if rat1Esp>16  & rat1Esp!=.
hist rat1Esp_alt4 


estimates drop _all

*baseline
eststo: xtivreg2 rat1Esp (IMFprogram = IVLQR) l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi  IMFprob   yeardummies* if sample== 1 ///
, fe cluster(countryID) first savefirst savefprefix(tabfirst11)
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local controls="Yes"
estadd local coding= "21 categories (baseline)"

*alt1
eststo: xtivreg2 rat1Esp_alt1 (IMFprogram = IVLQR) l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  IMFprob   yeardummies* if sample== 1 ///
, fe cluster(countryID) first savefirst savefprefix(tabfirst15)
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local controls="Yes"
estadd local coding= "10 categories"

*alt2
eststo: xtivreg2 rat1Esp_alt2 (IMFprogram = IVLQR) l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  IMFprob   yeardummies* if sample== 1 ///
, fe cluster(countryID) first savefirst savefprefix(tabfirst16)
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local controls="Yes"
estadd local coding= "7 categories"

*alt3
eststo: xtivreg2 rat1Esp_alt3 (IMFprogram = IVLQR) l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi  IMFprob   yeardummies* if sample== 1 ///
, fe cluster(countryID) first savefirst savefprefix(tabfirst17)
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local controls="Yes"
estadd local coding= "binary (threshold BBB)"

* alt4
 eststo: xtivreg2 rat1Esp_alt4 (IMFprogram = IVLQR) l4.($control)  l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob   yeardummies* if sample== 1 ///
 , fe cluster(countryID) first savefirst savefprefix(tabfirst18)
 estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local controls="Yes"
estadd local coding= "binary (threshold A)"



estout  using "output/TABLEA8_OTHER_RATING_CODING.txt", title("Alternative coding of ratings") ///
 replace  delimiter(_tab) nolabel noabbrev style(tab) keep(IMFprogram  ) ///
 collabels(none) mlabel("(1)" "(2)" "(3)" "(4)" "(5)") ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
 stats(N CountryFE YearFE controls  idp widstat coding , fmt(0 0 0 0 3 3 0) ///
 label("Observations" "Country FE" "Year FE"  "Controls(t-4)" "KP underid. p-value" "KP weak id. F-stat" "Coding of Credit Ratings")) 

 /*
 estout tabfirst1* using "output/TABLE_OTHER_RATING_CODING.txt",  ///
 append delimiter(_tab) nolabel noabbrev style(tab) extracols(1, 1 ,1 ,1, 1) ///
  collabels(none)  ///
  cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
  keep(IVLQR IMFprob ) order( IVLQR  IMFprob) mlabel(none)  /// 
  varlabels(IVLQR "IMF liquidity x IMF probability" IMFprob "IMF probability")  
*/

  

  
  
  
  
  


* Appendix A9: Placebo IVs

		   

	use  "processed/IMFRATING2.dta",clear	

	cap drop sample
	xtivreg2 rat1Esp (IMFprogram = IVLQR)  IMFprob l4.($control)  yeardummies*, fe cluster(countryID) first savefirst savefprefix(tabfirst17)
	gen sample= 1 if e(sample)

	cap est drop taba5*

	*IV global cycle controls
	cap drop IVgrowth IVcrises IVgrowthhic IVfdi
	gen IVgrowth = IMFprob * worldGDPgrowth
	gen IVcrises = IMFprob * crises_LV 
	gen IVfdi = IMFprob * d1_fdiin2gdp_hic
	
	
	*All other controls times liquidity as controls
	sort countryID year
	foreach var of varlist $control {
	gen `var'Xliquid = `var' * lnIMFgrossliquidity
	gen l4_`var'Xliquid = l4.`var'Xliquid
	}
		
		*placebo regressions

		xtivreg2 rat1Esp (IMFprogram = IVLQR) 		l4.($control)   IMFprob l4_*   yeardummies* if sample== 1, fe cluster(countryID) first  savefirst savefprefix(tabfirsta51)
		est store taba51
			estadd local CountryFE = "Yes"
			estadd local YearFE = "Yes"
			estadd local controls="Yes"
			
		xtivreg2 rat1Esp (IMFprogram = IVgrowth) IVLQR	l4.($control)   IMFprob  l4_* yeardummies* if sample== 1, fe cluster(countryID) first  savefirst savefprefix(tabfirsta52)
		est store taba52
			estadd local CountryFE = "Yes"
			estadd local YearFE = "Yes"
			estadd local controls="Yes"
			
		xtivreg2 rat1Esp (IMFprogram = IVcrises) IVLQR 	l4.($control)   IMFprob  l4_* yeardummies* if sample== 1, fe cluster(countryID) first  savefirst savefprefix(tabfirsta53)
		est store taba53
			estadd local CountryFE = "Yes"
			estadd local YearFE = "Yes"
			estadd local controls="Yes"
			
		xtivreg2 rat1Esp (IMFprogram = IVfdi) 	IVLQR	l4.($control)   IMFprob l4_*  yeardummies* if sample== 1, fe cluster(countryID) first  savefirst savefprefix(tabfirsta54)
		est store taba54
			estadd local CountryFE = "Yes"
			estadd local YearFE = "Yes"
			estadd local controls="Yes"


		estout taba5* using "output/PLACEBO_IVs.txt", title("Table - PLACEBO IVs") ///
		 replace  delimiter(_tab) nolabel noabbrev style(tab) keep(IMFprogram  ) ///
		 collabels(none) mlabel("(1)" "(2)" "(3)" "(4)" "(5)") ///
		 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
		 stats(N CountryFE YearFE controls  idp widstat , fmt(0 0 0 0 3 3 0) ///
		 label("Observations" "Country FE" "Year FE"  "Controls(t-4)" "KP underid. p-value" "KP weak id. F-stat")) 

	 
	 estout tabfirsta5* using "output/PLACEBO_IVs.txt",  ///
	 append delimiter(_tab) nolabel noabbrev style(tab)  ///
	  collabels(none)  ///
	  cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
	  keep(IVLQR IVgrowth IVcrises IVfdi IMFprob ) order( IVLQR IVgrowth IVcrises IVfdi IMFprob) mlabel(none)  /// 
	  varlabels(IVLQR "IMF liquidity x IMF probability" IVgrowth "Global growth x IMF probability" IVcrises "Global crises x IMF probability" IVfdi "FDI flows x IMF probability" IMFprob "IMF probability")  

			  
		  
		  
		  
		  
 
 
 
*Appendix E: LIQUIDITY AND GLOBAL CYCLES
 
 use  "processed/IMFRATING2",clear
 
corr worldGDPgrowth lnIMFgrossliquidity
twoway (line worldGDPgrowth year, yaxis(1) ytitle("Global GDP Growth", axis(1)) lpattern(dash) lcolor(gs8))  ///
(line lnIMFgrossliquidity year, lcolor(black) yaxis(2) ytitle("IMF Liquidity", axis(2))) if country_name == "Germany" ///
, scheme(s1mono) ///
legend(order(1 2) label(1 "Global GDP Growth") label(2 "IMF Liquidity")) /// 
 text(-0.01 1992 "correlation: r = -0.17")
 	graph export "output/FIGUREA2_GROWTHTREND.png", replace
	
scatter worldGDPgrowth lnIMFgrossliquidity, scheme(plotplain) ///
ytitle("Global GDP Growth") xtitle("IMF Liquidity")
 	graph export "output/FIGUREA3_GROWTHCORR.png", replace

	*crises
 corr  crises_LV lnIMFgrossliquidity
 twoway (line crises_LV year, yaxis(1) ytitle("Systemic Banking Crises", axis(1)) lpattern(dash) lcolor(gs8) )  ///
(line lnIMFgrossliquidity year, lcolor(black) yaxis(2) ytitle("IMF Liquidity", axis(2))) if country_name == "Germany" ///
, scheme(s1mono) ///
legend(order(1 2) label(1 "Systemic Banking Crises") label(2 "IMF Liquidity")) /// 
 text(2 1995 "correlation: r = 0.22")
 	graph export "output/FIGUREA4_CRISES.png", replace
	
	 scatter  crises_LV lnIMFgrossliquidity, scheme(plotplain) ///
ytitle("Systemic Banking Crises") xtitle("IMF Liquidity")
 	graph export "output/FIGUREA5_CRISESCORR.png", replace

	*FDI flows
sort year
corr d1_fdiin2gdp_hic lnIMFgrossliquidity
 twoway (line d1_fdiin2gdp_hic year if year <= 2012, yaxis(1) ytitle("FDI Flows to Emerging Economies", axis(1)) lpattern(dash) lcolor(gs8) )  ///
(line lnIMFgrossliquidity year, lcolor(black) yaxis(2) ytitle("IMF Liquidity", axis(2))) ///
, scheme(s1mono) ///
legend(order(1 2) label(1 "FDI to Emerging Economies (% GDP)") label(2 "IMF Liquidity")) /// 
 text(-4 1995 "correlation: r = -0.21")
  	graph export "output/FIGUREA6_FDI.png", replace
	
		 scatter  d1_fdiin2gdp_hic lnIMFgrossliquidity, scheme(plotplain) ///
ytitle("FDI to Emerging Economies (% GDP)") xtitle("IMF Liquidity")
 	graph export "output/FIGUREA7_FDICORR.png", replace
	
	
 
 
 


* FIGURE A8: Placebo Liquidity and Placebo Probability

* ATTENTION: NEEDS SEVERAL HOURS TO COMPUTE!


use  "processed/IMFRATING2.dta",clear	
		
		mat A1 = J(1000,1,.)
		mat B1 = J(1000,1,.)

		quietly{
		forvalues i=1(1)1000 {
			cap drop random 
			cap drop	rindex 
			cap drop new_IVLQR 
			cap drop new_lnIMFgrossliquidity
			bys  countryID  (year): gen random = runiform()
			bys countryID (random): gen rindex = _n
			bys countryID (year): gen new_lnIMFgrossliquidity=lnIMFgrossliquidity[rindex]
			bys countryID (year): gen new_IVLQR = IMFprob*new_lnIMFgrossliquidity
			
			xtivreg2 rat1Esp IMFprogram  IVLQR  IMFprob ,fe
			xtivreg2 IMFprogram  new_IVLQR  IMFprob   yeardummies* if e(sample), fe cluster(countryID) 

			mat A1[`i',1] = _b[new_IVLQR]	
			mat B1[`i',1] = _se[new_IVLQR]		
		}
		}
		mat li A1
		mat li B1
		svmat A1
		svmat B1

		mean A1
		gen t0 = A1/B1
		gen t1 = abs(A1/B1)

		xtivreg2 rat1Esp IMFprogram  IVLQR  IMFprob ,fe

		xtivreg2 IMFprogram  IVLQR  IMFprob   yeardummies* if e(sample), fe cluster(countryID)
		cap drop p1 pv1
		scalar b1=_b[IVLQR]
		scalar list b1

		gen p1 = (t1>  abs(_b[IVLQR]/_se[IVLQR])) if !missing(t1)
		sum p1	/*The p-values are estimated as the proportion of times that the absolute value of the t-statistics in replication data exceed the absolute value of the original t-statistic.*/	
		gen pv1=r(mean)
		scalar pv1=pv1	
		
				* VL (28May) I think the last step is wrong, it should be
				scalar  t_real = abs(_b[IVLQR]/_se[IVLQR])
				scalar list t_real
				hist t1
	
				
			
		*(kdensity A1,range(-1 1))
		twoway kdensity A1 ,  title("") scheme(s2mono) graphregion(color(white)) ///
		ytitle("Density", size(large)) xtitle("Point Coefficent", size(large)) title("First Stage Coefficient: Randomizing Liquidity", size(large))  /// //xline(`=scalar(b1)',lpattern(dash)) note("p-value: `=scalar(pv1)'") 	
		yline(0, lwidth( medsmall ) lcolor(black) )   legend(off) 		///
		range(-0.2  0.2)  ///
		xtitle("Coefficient size", margin(small)) ///
		ytitle("Density", margin(small))
		
			graph export "output/FIGUREA8_randomization_liquidity.png", replace

	
	
	
	
	
* FIGURE A9: Placebo Liquidity and Placebo Probability

*B: Assign probability randomly  - As expected, instrument works less well now, supports that cross-sectional variation is crucial
		
		
		use  "processed/IMFRATING2.dta",clear	
		
		mat A2 = J(1000,1,.)
		mat B2 = J(1000,1,.)

		quietly{
		forvalues i=1(1)1000 {
			cap drop random rindex new_IVLQR 
			bys  year (countryID): gen random = runiform()
			bys year (random): gen rindex = _n
			bys year (countryID): gen new_IVLQR = IMFprob[rindex]*lnIMFgrossliquidity
			
			xtivreg2 rat1Esp IMFprogram  IVLQR  IMFprob ,fe
			xtivreg2 IMFprogram  new_IVLQR  IMFprob   yeardummies* if e(sample) , fe cluster(countryID)

			mat A2[`i',1] = _b[new_IVLQR]	
			mat B2[`i',1] = _se[new_IVLQR]		
		}
		}
		mat li A2
		mat li B2
		svmat A2
		svmat B2

		mean A2
		gen t1 = abs(A2/B2)
		
		xtivreg2 rat1Esp IMFprogram  IVLQR  IMFprob ,fe
		xtivreg2 IMFprogram  IVLQR  IMFprob   yeardummies* if e(sample), fe cluster(countryID) 
		cap drop p1 pv1
		scalar b1=_b[IVLQR]
		
		cap gen p1 = (t1>  abs(_b[IVLQR]/_se[IVLQR])) if !missing(t1)
		sum p1	/*The p-values are estimated as the proportion of times that the absolute value of the t-statistics in replication data exceed the absolute value of the original t-statistic.*/	
		cap gen pv1=r(mean)
		scalar pv1=pv1	
		
		*(kdensity A1,range(-1 1))
		twoway kdensity A2,  title("") scheme(s2mono) graphregion(color(white)) ///
		ytitle("Density", size(large)) xtitle("Point Coefficent", size(large)) title("First Stage Coefficient: Randomizing Probability", size(large))  /// // xline(`=scalar(b1)',lpattern(dash)) note("p-value: `=scalar(pv1)'")		///
		yline(0, lwidth( medsmall ) lcolor(black) )   legend(off) 		///
		range( -0.05 0.05) ///
		xtitle("Coefficient size", margin(small)) ///
		ytitle("Density", margin(small))
		
		graph export "output/FIGUREA9_randomization_probability.png", replace

 





 

*FIGURE A10: HETEROGENEITY


use "processed/IMFRATING2.dta", clear


  global control		ln_gdp_pc_const gdp_growth inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

					

			*IV global cycle controls
	cap drop IVgrowth IVcrises IVgrowthhic IVfdi
	gen IVgrowth = IMFprob * worldGDPgrowth
	gen IVcrises = IMFprob * crises_LV 
	gen IVfdi = IMFprob * d1_fdiin2gdp_hic
	
	
	*All other controls times liquidity as controls
		sort countryID year
		foreach var of varlist $control {
		gen `var'Xliquid = `var' * lnIMFgrossliquidity
		gen l4_`var'Xliquid = l4.`var'Xliquid
		}
		

*rating sample
xtivreg2 rat1Esp (IMFprogram = IVLQR) l4.($control)   IMFprob   yeardummies* , fe cluster(countryID)  
gen sample1 = 1 if e(sample)

*bond sample
xtivreg2 bondspread_last_yearly  (IMFprogram = IVLQR) IMFprob  yeardummies*, fe cluster(countryID) 
gen sample2 = 1 if e(sample)


*if bondspreads are available
gen bond = 0
replace bond = 1 if bondspread_last_yearly != .
tab country if bond == 0 & rat1Esp != . & sample1 ==1 
tab year if bond == 0 & rat1Esp != . & sample1 ==1 
replace bond = 1 if code == "USA"
replace bond = 1 if code == "LUX"

cap est drop taba3*


xtivreg2 rat1Esp (IMFprogram = IVLQR) l4.($control)   l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob    yeardummies* if bond == 0 , fe cluster(countryID)  
est store taba31
estadd local sample = "bond price not available"

xtivreg2 rat1Esp (IMFprogram = IVLQR) l4.($control)   l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob    yeardummies* if bond == 1 , fe cluster(countryID)  
est store taba32
estadd local sample = "bond price available"

*GDP
sum l4.ln_gdp_pc_const if sample1 == 1, detail // mean is 9
xtivreg2 rat1Esp (IMFprogram = IVLQR) l4.($control)   l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob    yeardummies* if l.ln_gdp_pc_const < `r(p50)' , fe cluster(countryID)  
est store taba33
estadd local sample = "GDP per capita < sample median"

sum l4.ln_gdp_pc_const if sample1 == 1, detail // mean is 9
xtivreg2 rat1Esp (IMFprogram = IVLQR) l4.($control)   l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob    yeardummies* if l.ln_gdp_pc_const > `r(p50)' , fe cluster(countryID)  
est store taba34
estadd local sample = "GDP per capita > sample median"

/*
*Debt-to-GDP above and below median, mean 60,...
sum l4.DebtGDP if sample1 == 1, detail
xtivreg2 rat1Esp (IMFprogram = IVLQR) IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob  yeardummies* if sample1 == 1 & l.DebtGDP > `r(p50)', fe cluster(countryID)  
est store taba35
estadd local sample = "debt ratio > median"

sum l4.DebtGDP if sample1 == 1, detail
xtivreg2 rat1Esp (IMFprogram = IVLQR) IMFprob l4.($control) l4_*Xliquid IVgrowth IVcrises IVfdi IMFprob  yeardummies* if sample1 == 1 & l.DebtGDP <= `r(p50)', fe cluster(countryID)  
est store taba36
estadd local sample = "debt ratio < median"
*/

estout taba3* using "output/TableA10_heterogeneity.txt", title("Table A10 - Heterogeneity") ///
 replace  delimiter(_tab) nolabel noabbrev style(tab) keep(IMFprogram  ) ///
 collabels(none) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
 stats(N idp widstat sample, fmt(0 3 3 9) ///
 label("Observations" "KP underid. (p)" "KP weak id. (F)" "Sample")) 

	
  

 
 

 
 
  
 *Appendix M: Monthly Table
 
 
use "processed/IMFRATINGMONTHLY2.dta", clear

xtset countryID monthcount
sort countryID monthcount

*no FE
reg rat1Esp f11.IMFstart f10.IMFstart f9.IMFstart f8.IMFstart f7.IMFstart f6.IMFstart f5.IMFstart f4.IMFstart f3.IMFstart f2.IMFstart f1.IMFstart IMFstart ///
			l.IMFstart l2.IMFstart l3.IMFstart l4.IMFstart l5.IMFstart l6.IMFstart l7.IMFstart l8.IMFstart l9.IMFstart l10.IMFstart l11.IMFstart ///
				, robust
est store tabm1
estadd local cFE "No"
estadd local yFE "No"
estadd local cyFE "No"
estadd local mFE "No"

*country, year
reghdfe rat1Esp  f11.IMFstart f10.IMFstart f9.IMFstart f8.IMFstart f7.IMFstart f6.IMFstart f5.IMFstart f4.IMFstart f3.IMFstart f2.IMFstart f1.IMFstart IMFstart ///
				l.IMFstart l2.IMFstart l3.IMFstart l4.IMFstart l5.IMFstart l6.IMFstart l7.IMFstart l8.IMFstart l9.IMFstart l10.IMFstart l11.IMFstart  ///
				, absorb(countryID year) vce(robust)
est store tabm2
estadd local cFE "Yes"
estadd local yFE "Yes"
estadd local cyFE "No"
estadd local mFE "No"
*countryXyear
reghdfe rat1Esp f11.IMFstart f10.IMFstart f9.IMFstart f8.IMFstart f7.IMFstart  f6.IMFstart f5.IMFstart f4.IMFstart f3.IMFstart f2.IMFstart f1.IMFstart IMFstart ///
				l.IMFstart l2.IMFstart l3.IMFstart l4.IMFstart l5.IMFstart l6.IMFstart  l7.IMFstart l8.IMFstart l9.IMFstart l10.IMFstart l11.IMFstart  ///
				, absorb(countryID#year) vce(robust)
est store tabm3
estadd local cFE "Yes"
estadd local yFE "Yes"
estadd local cyFE "Yes"
estadd local mFE "No"


*countryXyear, month
reghdfe rat1Esp f11.IMFstart f10.IMFstart f9.IMFstart f8.IMFstart f7.IMFstart  f6.IMFstart f5.IMFstart f4.IMFstart f3.IMFstart f2.IMFstart f1.IMFstart IMFstart ///
				l.IMFstart l2.IMFstart l3.IMFstart l4.IMFstart l5.IMFstart l6.IMFstart  l7.IMFstart l8.IMFstart l9.IMFstart l10.IMFstart l11.IMFstart  ///
				, absorb(countryID#year monthcount) vce(robust)
est store tabm4
estadd local cFE "Yes"
estadd local yFE "Yes"
estadd local cyFE "Yes"
estadd local mFE "Yes"


 estout tabm* using "output/TableA11_monthly.txt", title("Table - Monthly") ///
 replace  delimiter(_tab) label noabbrev style(tab)  collabels(none) ///
 cells(b(star fmt(3))) ///
 mlabel("(1)" "(2)" "(3)" "(4)") ///
 stats(cFE yFE cyFE mFE N r2_a, fmt(0  3) label("Country FE" "Year FE" "Country x Year FE" "Month FE" "Observations" "Adjusted R-squared")) 


 
 
 
 
 
 

 

 
 
 
 
***Appendix J: Replication with BOND SPREADS

use "processed/IMFRATING2.dta", clear

  global control		ln_gdp_pc_const gdp_growth inflation2 natresources populationln /// /*Domestic Economic Performance*/ 
					DebtGDP ChangeGovDebtGDP   Ddefault default5 /// /*Financial Stability and Fiscal Performance*/ 
					openness cab  extdebtgdp0 DEuro /// /*External Performance */ 
					LawOrder polity2 election honeymoon left /// /*Political/Institutional Performance */ 
					InternalConflict ExternalConflict MilitaryPolL   /// Security Related
					investment  crisis_LV bankexp_fi  idealpointUS    // IMF controls

					

	*IV global cycle controls
		cap drop IVgrowth IVcrises IVgrowthhic IVfdi
		gen IVgrowth = IMFprob * worldGDPgrowth
		gen IVcrises = IMFprob * crises_LV 
		gen IVfdi = IMFprob * d1_fdiin2gdp_hic
		
	
	*All other controls times liquidity as controls
		sort countryID year
		foreach var of varlist $control {
		gen `var'Xliquid = `var' * lnIMFgrossliquidity
		gen l4_`var'Xliquid = l4.`var'Xliquid
		}
		
	*first differences of controls
		cap drop d45X* 
		foreach var of varlist $control {
		gen d45X_`var' = l4.`var' - l5.`var'
		}
	
estimates drop _all
cap est drop taba1* tabfirsta1*
cap drop sample
xtivreg2 bondspread_last_yearly (IMFprogram = IVLQR)  IMFprob l4.($control)  yeardummies*, fe cluster(countryID) 
gen sample2= 1 if e(sample)


*Availability of spread vs. rating
gen spread_avail=.
replace spread_avail =1 if bondspread_last_yearly!=.
gen rat_avail=.
replace rat_avail=1 if rat1Esp!=.



 ****Year end spreads
estimates drop _all
  *Column 1
reg bondspread_last_yearly IMFprogram  if sample2== 1, cluster(countryID) // for constant sample for comparability
est store taba11
estadd local CountryFE = "No"
estadd local YearFE = "No"
estadd local Method = "OLS"
estadd local controls="No"
*Column 2
xtreg bondspread_last_yearly IMFprogram  if sample2== 1, fe cluster(countryID)
est store taba12
estadd local CountryFE = "Yes"
estadd local YearFE = "No"
estadd local Method = "FE"
estadd local controls="No"
*Column 3
xtreg bondspread_last_yearly IMFprogram yeardummies*  if sample2== 1, fe cluster(countryID)
est store taba13
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local Method = "FE"
estadd local controls="No"

*Column 4
xtivreg2 bondspread_last_yearly IMFprogram  l4.($control) yeardummies* if sample2== 1, fe cluster(countryID)
est store taba14
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local controls="Yes"
estadd local Method = "FE + controls"


*Column 5
rename IMFprogram IMFprogramreal
rename IMFagreement IMFprogram

reg d1.bondspread_last_yearly IMFprogram d45X* yeardummies* if sample2== 1,  cluster(countryID)
est store taba15
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local controls="Yes"
estadd local Method = "FD"

rename  IMFprogram IMFagreement
rename  IMFprogramreal IMFprogram

*Column 6
xtivreg2 bondspread_last_yearly (IMFprogram = IVLQR) l4.($control)  IVgrowth IVcrises IVfdi l4_*  IMFprob   yeardummies* if sample2== 1, fe cluster(countryID) first savefirst savefprefix(tabfirsta16)
est store taba16
estadd local CountryFE = "Yes"
estadd local YearFE = "Yes"
estadd local controls="Yes"
estadd local Method = "IV"


estout taba1* using "output/TableA12_spreads.txt", title("Table A1 - Spreads") ///
 replace  delimiter(_tab) label noabbrev style(tab) collabels(none) /// 
 keep(IMFprogram) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
 stats(N r2 CountryFE YearFE controls idp widstat, fmt(0 3 0 0 0 3 3) ///
 label("Observations" "Adjusted R-squared" "Country FE" "Year FE"  "Controls (t-4)"  "KP underid. p" "KP weak id. (F)")) 

 estout tabfirsta1* using "output/TableA12_spreads.txt",  ///
 append delimiter(_tab)  label noabbrev style(tab)  collabels(none) ///
 extracols(1, 1 ,1 ,1, 1) ///
 cells(b(star fmt(3) nostar) se(par([ ]) abs fmt(3)) p(par({ }) abs fmt(3))) ///
  keep(IMFprob IVLQR  ) order( IVLQR  IMFprob)  mlabel(none) //
 
	
  coefplot (taba11, mcolor(cranberry) msymbol(S) ciopts(lcolor(cranberry)) label("Bond Yield Spreads")) 	 ///
		(taba12, mcolor(cranberry) msymbol(circle) ciopts(lcolor(cranberry)) nokey) 	  ///
		(taba13, mcolor(cranberry) msymbol(circle_hollow) ciopts(lcolor(cranberry))nokey)    ///
		(taba14, mcolor(cranberry) msymbol(D) ciopts(lcolor(cranberry))nokey) 		  ///
		(taba15, mcolor(cranberry)  msymbol(Dh) ciopts(lcolor(cranberry))nokey) 	  ///
		(taba16, mcolor(cranberry)  msymbol(T) ciopts(lcolor(cranberry))nokey) 	  ///
			, keep(IMFprogram ) level(90) vertical noeqlabels rename(IMFprogram = "_")   ///
			text(200 0.64 "(1)" "OLS", size(small)) text(-100 0.785 "(2)" "OLS-FE", size(small)) text(-125 0.93 "(3)" "OLS-FE", size(small)) text(-150 1.07 "(4)" "OLS-FE", size(small)) text(-200 1.215 "(5)" "OLS-FD", size(small)) text(-900 1.356 "(6)" "IV", size(small))  ///
			scheme(plotplain) yline(0, lcolor(black))
			graph export "output/FIGURE_A11_COEFPLOTSPREADS.png", replace


			
			
			
			
			
			
		
* BOND SPREADS MONTHLY			

use "processed/IMFRATINGMONTHLY2.dta", clear

xtset countryID monthcount
sort countryID monthcount


 

*This graph for the paper in a nice version:

	*labels
	quietly{
	forvalues i = 1(1)11 {
	cap gen f`i'_IMFstart = f`i'.IMFstart
	label var f`i'_IMFstart "-`i'"			
	cap gen l`i'_IMFstart = l`i'.IMFstart
	label var l`i'_IMFstart "`i'"			
	}
	}
	label var IMFstart "0"

reghdfe bondspread_monthly f11_IMFstart f10_IMFstart f9_IMFstart f8_IMFstart f7_IMFstart  f6_IMFstart f5_IMFstart f4_IMFstart f3_IMFstart f2_IMFstart f1_IMFstart IMFstart ///
				l1_IMFstart l2_IMFstart l3_IMFstart l4_IMFstart l5_IMFstart l6_IMFstart  l7_IMFstart l8_IMFstart l9_IMFstart l10_IMFstart l11_IMFstart  ///
				, absorb(countryID#year monthcount) vce(robust)
est store tabm4
			coefplot tabm4, drop(_cons) vertical ///
			xlabel(, labsize(medsmall) angle(horizontal) ) ///
			ylabel(, labsize(medsmall)) ///
					graphregion(color(white))  mcolor(black) msymbol(O) ///
								   xtitle("IMF agreement, leads / lags of x months" , color(black) size(medium) margin(medium)) yline(0, lcolor(cranberry)) ///
								   ytitle("Effect on bond yield spreads in month m", color(black) size(medium)) ylabel(,nogrid) xline(12, lcolor(cranberry)) ///
								title("", color(black) size(medium)) ///
								yscale(range(-50 180)) ciopts(lcolor(black)) ///
								xsize(6) ysize(4) level(90) ///
								xlabel(1 "-11" 3 "-9" 6 "-6" 9 "-3" 12 "0" 15 "+3" 18 "+6" 21 "+9" 23 "+11") ///
								ylabel(-50(50)250) ///
								scheme(plotplain)
								graph export "output/coefplot_monthly_spreads.png", replace width(3000) height(2000)
					
				

				
				
*FIGURE A13: MONTHLY SPREADS: Difference Period 0 und X 			
xtset countryID monthcount
sort countryID monthcount						
				
mat A=J(22,2,0)

local no = 1
reghdfe S11.bondspread_monthly  	IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1				
reghdfe S10.bondspread_monthly  	IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S9.bondspread_monthly   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S8.bondspread_monthly   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S7.bondspread_monthly   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S6.bondspread_monthly   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S5.bondspread_monthly   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1	
reghdfe S4.bondspread_monthly   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe S3.bondspread_monthly   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe S2.bondspread_monthly   	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe S1.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe f1.S1.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1		
reghdfe f2.S2.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
					
reghdfe f3.S3.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1
reghdfe f4.S4.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f5.S5.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f6.S6.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f7.S7.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f8.S8.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f9.S9.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)					
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'
local no = `no'+1					
reghdfe f10.S10.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)						
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'					
local no = `no'+1
reghdfe f11.S11.bondspread_monthly  	   IMFstart   ///
					, absorb(countryID#year monthcount) vce(robust)						
					scalar b`no' = _b[IMFstart]
scalar s`no' = _se[IMFstart]
matrix A[`no', 1] =  b`no'
matrix A[`no', 2] =  s`no'		


coefplot matrix(A[,1]), se(A[,2]) xtitle("months (m) before / after IMF agreement" , color(black) margin(medium)) levels(90) ciopts(lcolor(black)) ///
ytitle("Effect of IMF agreement "  "on bond spread in month x" , color(black) margin(medium)) ///
yline(0, lcolor(cranberry)) xline(11.5, lcolor(cranberry)) vertical graphregion(color(white)) ///
mcolor(black) xsize(6) ysize(4) xlabel(1 "-11" 3 "-9" 6 "-6" 9 "-3" 11.5 "m" 14 "+3" 17 "+6" 20 "+9" 22 "+11")  ylabel(,nogrid angle(0)) ///
scheme(plotplain) msymbol(O) ///
ylabel(, labsize(medmall)) xlabel(, labsize(medsmall))
graph export "output/coefplot_monthly_spreads_difference.png", replace












